(* ::Package:: *)

(*:Package Version: 2.02 *)

(*:Version History: 1.01 (1999.07.01 - 2006.04.01)
                    1.02 (2006.04.02 - 2010.12.11)
                    2.01 (2010.12.12 - 2014.11.07)
                    2.02 (2014.11.08 -     .  .  ) *)

(*:Copyright: Copyright 1999.7-2014.11, Souichiro Ikebe *)

(*:Author: Souichiro Ikebe *)

(*:Name: QSpecialFunctions`QSeries` *)

(*:Title: MockTheta, Andrews, Rogers-Ramanujan *)

(*:Keywords: OrigQSF, PartitionPGeneratingFunction, 
     SecondMockThetaA, SecondMockThetaB, SecondMockThetaMu, 
     ThirdMockThetaF, ThirdMockThetaPhi, ThirdMockThetaPsi, 
     ThirdMockThetaChi, ThirdMockThetaRho, ThirdMockThetaOmega, 
     ThirdMockThetaNu, ThirdMockThetaChi, ThirdMockThetaRho, 
     FifthMockThetaF0, FifthMockThetaF1, FifthMockThetaPhi0, 
     FifthMockThetaPhi1, FifthMockThetaPsi0, FifthMockThetaPsi1, 
     FifthMockThetaChi0, FifthMockThetaChi1, FifthMockThetaLargeF0, 
     FifthMockThetaLargeF1, 
     SixthMockThetaPhi, SixthMockThetaPsi, SixthMockThetaRho, 
     SixthMockThetaSigma, SixthMockThetaLambda, SixthMockThetaMu, 
     SixthMockThetaGamma, 
     SeventhMockThetaF0, SeventhMockThetaF1, SeventhMockThetaF2, 
     AndrewsMockTheta3, AndrewsMockTheta5, AndrewsMockTheta7, 
     AndrewsMockTheta3Cos, AndrewsMockTheta5Cos, AndrewsMockTheta7Cos, 
     RogersRamanujanR1, RogersRamanujanR2, RogersRamanujanC, 
     GeneralizedRogersRamanujanR, GeneralizedRogersRamanujanF, 
     BaileyMod9First, BaileyMod9Second, BaileyMod9Third, 
     RogersMod14First, RogersMod14Second, RogersMod14Third, 
     RogersSelbergFirst, RogersSelbergSecond, RogersSelbergThird, 
     GoellnitzGordonFirst, GoellnitzGordonSecond, JacksonSlater, 
     DysonMod27First, DysonMod27Second, DysonMod27Third, 
     DysonMod27Fourth *)

(*:Sources: 

  George E.Andrews, Mock Theta Functions, 
  Proceedings of Symposia in Pure Mathematics vol .49,
  (1989), part2, pp283-298.
*)

(*:Summary:
 
  This package implements the mock theta functions, some infinity 
  product from q-Analysis. 
  Rogers-Ramanujan continued fraction, and more. 
*)

(**************************************************************)





BeginPackage["QSpecialFunctions`QSeries`",
"QSpecialFunctions`QElementaryFunction`"]





OrigQSF::usage =
"OrigQSF[q,{n,m}] gives the original q-shifted factorial.
 It's evaluated of Product[(1-q^(n+m i)),{i,0,infinity}]."

PartitionPGeneratingFunction::usage =
"PartitionPGeneratingFunction[q] gives the Euler's
 generating function P(q) of the partition numbers p(n)."


SecondMockThetaA::usage =
"SecondMockThetaA[q] gives the McIntosh's second order
 mock theta function A(q)."

SecondMockThetaB::usage =
"SecondMockThetaB[q] gives the McIntosh's second order
 mock theta function B(q)."

SecondMockThetaMu::usage =
"SecondMockThetaMu[q] gives the McIntosh's second order
 mock theta function Mu(q)."


ThirdMockThetaF::usage =
"ThirdMockThetaF[q] gives the Ramanujan's third order
 mock theta function f(q)."

ThirdMockThetaPhi::usage =
"ThirdMockThetaPhi[q] gives the Ramanujan's third order
 mock theta function phi(q)."

ThirdMockThetaPsi::usage =
"ThirdMockThetaPsi[q] gives the Ramanujan's third order
 mock theta function psi(q)."

ThirdMockThetaOmega::usage =
"ThirdMockThetaOmega[q] gives the Ramanujan's third order
 mock theta function omega(q)."

ThirdMockThetaNu::usage =
"ThirdMockThetaNu[q] gives the Ramanujan's third order
 mock theta function Nu(q)."

ThirdMockThetaChi::usage =
"ThirdMockThetaChi[q] gives the Ramanujan's third order
 mock theta function chi(q)."

ThirdMockThetaRho::usage =
"ThirdMockThetaRho[q] gives the Ramanujan's third order
 mock theta function rho(q)."


FifthMockThetaF0::usage =
"FifthMockThetaF0[q] gives the Ramanujan's fifth order
 mock theta function f0(q)."

FifthMockThetaF1::usage =
"FifthMockThetaF1[q] gives the Ramanujan's fifth order
 mock theta function f1(q)."

FifthMockThetaPhi0::usage =
"FifthMockThetaPhi0[q] gives the Ramanujan's fifth order
 mock theta function phi0(q)."

FifthMockThetaPhi1::usage =
"FifthMockThetaPhi1[q] gives the Ramanujan's fifth order
 mock theta function phi1(q)."

FifthMockThetaPsi0::usage =
"FifthMockThetaPsi0[q] gives the Ramanujan's fifth order
 mock theta function psi0(q)."

FifthMockThetaPsi1::usage =
"FifthMockThetaPsi1[q] gives the Ramanujan's fifth order
 mock theta function psi1(q)."

FifthMockThetaChi0::usage =
"FifthMockThetaChi0[q] gives the Ramanujan's fifth order
 mock theta function chi0(q)."

FifthMockThetaChi1::usage =
"FifthMockThetaChi1[q] gives the Ramanujan's fifth order
 mock theta function chi1(q)."

FifthMockThetaLargeF0::usage =
"FifthMockThetaLargeF0[q] gives the Ramanujan's fifth order
 mock theta function F0(q)."

FifthMockThetaLargeF1::usage =
"FifthMockThetaLargeF1[q] gives the Ramanujan's fifth order
 mock theta function F1(q)."


SixthMockThetaPhi::usage =
"SixthMockThetaPhi[q] gives the Ramanujan's sixth order
 mock theta function phi(q)."

SixthMockThetaPsi::usage =
"SixthMockThetaPsi[q] gives the Ramanujan's sixth order
 mock theta function psi(q)."

SixthMockThetaRho::usage =
"SixthMockThetaRho[q] gives the Ramanujan's sixth order
 mock theta function rho(q)."

SixthMockThetaSigma::usage =
"SixthMockThetaSigma[q] gives the Ramanujan's sixth order
 mock theta function sigma(q)."

SixthMockThetaLambda::usage =
"SixthMockThetaLambda[q] gives the Ramanujan's sixth order
 mock theta function lambda(q)."

SixthMockThetaMu::usage =
"SixthMockThetaMu[q] gives the Ramanujan's sixth order
 mock theta function mu(q)."

SixthMockThetaGamma::usage =
"SixthMockThetaGamma[q] gives the Ramanujan's sixth order
 mock theta function gamma(q)."


SeventhMockThetaF0::usage =
"SeventhMockThetaF0[q] gives the Ramanujan's seventh order
 mock theta function F0(q)."

SeventhMockThetaF1::usage =
"SeventhMockThetaF1[q] gives the Ramanujan's seventh order
 mock theta function F1(q)."

SeventhMockThetaF2::usage =
"SeventhMockThetaF2[q] gives the Ramanujan's seventh order
 mock theta function F2(q)."


AndrewsMockTheta3::usage =
"AndrewsMockTheta3[q,t] gives the third mock theta
 functions definition by George E.Andrews."

AndrewsMockTheta5::usage =
"AndrewsMockTheta5[q,t] gives the fifth mock theta
 functions definition by George E.Andrews."

AndrewsMockTheta7::usage =
"AndrewsMockTheta7[q,t] gives the seventh mock theta
 functions definition by George E.Andrews."

AndrewsMockTheta3Cos::usage =
"AndrewsMockTheta3Cos[q,t] gives the third mock theta
 functions definition by George E.Andrews."

AndrewsMockTheta5Cos::usage =
"AndrewsMockTheta5Cos[q,t] gives the fifth mock theta
 functions definition by George E.Andrews."

AndrewsMockTheta7Cos::usage =
"AndrewsMockTheta7Cos[q,t] gives the seventh mock theta
 functions definition by George E.Andrews."



RogersRamanujanR1::usage =
"RogersRamanujanR1[q] gives the Rogers-Ramanujan first
 identity of q-series."

RogersRamanujanR2::usage =
"RogersRamanujanR2[q] gives the Rogers-Ramanujan second
 identity of q-series."


RogersRamanujanC::usage =
"RogersRamanujanC[q] gives the Rogers-Ramanujan continued fraction.
 It's evaluated of C[q]=Product[(1-q^(5k+1))*(1-q^(5k+4))/
 (1-q^(5k+2))/(1-q^(5k+3)),{k,0,infinity}] or 
 C[q]=q^(1/5)/(1+q/(1+q^2/(1+q^3...)))."

GeneralizedRogersRamanujanR::usage =
"GeneralizedRogersRamanujanR[a,b,q] gives the generalized 
 Rogers-Ramanujan continued fraction.
 It's evaluated of R[a,b,q]=a/(1+b+aq/(1+bq+aq^2/(1+bq^2+aq^3...)))."

GeneralizedRogersRamanujanF::usage =
"GeneralizedRogersRamanujanF[a,q] gives the little generalized 
 Rogers-Ramanujan continued fraction.
 It's evaluated of F[a,q]=1-aq/(1-aq^2/(1-aq^3...))."


BaileyMod9First::usage =
"BaileyMod9First[q] gives the Bailey's first identity of 
 q-series of Rogers-Ramanujan-type."

BaileyMod9Second::usage =
"BaileyMod9Second[q] gives the Bailey's second identity of 
 q-series of Rogers-Ramanujan-type."

BaileyMod9Third::usage =
"BaileyMod9Third[q] gives the Bailey's third identity of 
 q-series of Rogers-Ramanujan-type."


RogersMod14First::usage =
"RogersMod14First[q] gives the Rogers's first identity of 
 q-series of Rogers-Ramanujan-type."

RogersMod14Second::usage =
"RogersMod14Second[q] gives the Rogers's second identity of 
 q-series of Rogers-Ramanujan-type."

RogersMod14Third::usage =
"RogersMod14Third[q] gives the Rogers's third identity of 
 q-series of Rogers-Ramanujan-type."


RogersSelbergFirst::usage =
"RogersSelbergFirst[q] gives the Rogers-Selberg first identity of 
 q-series of Rogers-Ramanujan-type."

RogersSelbergSecond::usage =
"RogersSelbergSecond[q] gives the Rogers-Selberg second identity of 
 q-series of Rogers-Ramanujan-type."

RogersSelbergThird::usage =
"RogersSelbergThird[q] gives the Rogers-Selberg third identity of 
 q-series of Rogers-Ramanujan-type."


GoellnitzGordonFirst::usage =
"GoellnitzGordonFirst[q] gives the Goellnitz-Gordon first 
 identity of q-series of Rogers-Ramanujan-type."

GoellnitzGordonSecond::usage =
"GoellnitzGordonSecond[q] gives the Goellnitz-Gordon second 
 identity of q-series of Rogers-Ramanujan-type."


JacksonSlater::usage =
"JacksonSlater[q] gives the Jackson-Slater identity of 
 q-series of Rogers-Ramanujan-type."


DysonMod27First::usage =
"DysonMod27First[q] gives the Dyson's first identity of 
 q-series of Rogers-Ramanujan-type."

DysonMod27Second::usage =
"DysonMod27Second[q] gives the Dyson's second identity of 
 q-series of Rogers-Ramanujan-type."

DysonMod27Third::usage =
"DysonMod27Third[q] gives the Dyson's third identity of 
 q-series of Rogers-Ramanujan-type."

DysonMod27Fourth::usage =
"DysonMod27Fourth[q] gives the Dyson's fourth identity of 
 q-series of Rogers-Ramanujan-type."








Begin["QSpecialFunctions`QSeries`Private`"]







Attributes[PartitionPGeneratingFunction]={Listable}


Attributes[SecondMockThetaA]={Listable}

Attributes[SecondMockThetaB]={Listable}

Attributes[SecondMockThetaMu]={Listable}


Attributes[ThirdMockThetaF]={Listable}

Attributes[ThirdMockThetaPhi]={Listable}

Attributes[ThirdMockThetaPsi]={Listable}

Attributes[ThirdMockThetaOmega]={Listable}

Attributes[ThirdMockThetaNu]={Listable}

Attributes[ThirdMockThetaChi]={Listable}

Attributes[ThirdMockThetaRho]={Listable}


Attributes[FifthMockThetaF0]={Listable}

Attributes[FifthMockThetaF1]={Listable}

Attributes[FifthMockThetaPhi0]={Listable}

Attributes[FifthMockThetaPhi1]={Listable}

Attributes[FifthMockThetaPsi0]={Listable}

Attributes[FifthMockThetaPsi1]={Listable}

Attributes[FifthMockThetaChi0]={Listable}

Attributes[FifthMockThetaChi1]={Listable}

Attributes[FifthMockThetaLargeF0]={Listable}

Attributes[FifthMockThetaLargeF1]={Listable}


Attributes[SixthMockThetaPhi]={Listable}

Attributes[SixthMockThetaPsi]={Listable}

Attributes[SixthMockThetaRho]={Listable}

Attributes[SixthMockThetaSigma]={Listable}

Attributes[SixthMockThetaLambda]={Listable}

Attributes[SixthMockThetaMu]={Listable}

Attributes[SixthMockThetaGamma]={Listable}


Attributes[SeventhMockThetaF0]={Listable}

Attributes[SeventhMockThetaF1]={Listable}

Attributes[SeventhMockThetaF2]={Listable}


Attributes[AndrewsMockTheta3]={Listable}

Attributes[AndrewsMockTheta5]={Listable}

Attributes[AndrewsMockTheta7]={Listable}

Attributes[AndrewsMockTheta3Cos]={Listable}

Attributes[AndrewsMockTheta5Cos]={Listable}

Attributes[AndrewsMockTheta7Cos]={Listable}



Attributes[RogersRamanujanR1]={Listable}

Attributes[RogersRamanujanR2]={Listable}


Attributes[RogersRamanujanC]={Listable}

Attributes[GeneralizedRogersRamanujanR]={Listable}

Attributes[GeneralizedRogersRamanujanF]={Listable}


Attributes[BaileyMod9First]={Listable}

Attributes[BaileyMod9Second]={Listable}

Attributes[BaileyMod9Third]={Listable}


Attributes[RogersMod14First]={Listable}

Attributes[RogersMod14Second]={Listable}

Attributes[RogersMod14Third]={Listable}


Attributes[RogersSelbergFirst]={Listable}

Attributes[RogersSelbergSecond]={Listable}

Attributes[RogersSelbergThird]={Listable}


Attributes[GoellnitzGordonFirst]={Listable}

Attributes[GoellnitzGordonSecond]={Listable}


Attributes[JacksonSlater]={Listable}


Attributes[DysonMod27First]={Listable}

Attributes[DysonMod27Second]={Listable}

Attributes[DysonMod27Third]={Listable}

Attributes[DysonMod27Fourth]={Listable}






(**************************************************************)
(*                      OrigQSF[q,{n,m}]                      *)
(**************************************************************)

OrigQSF[q_,{n_,m_}]:=
  Module[{s=1,so=-1,qf},qf=q^n;
   While[so!=s,so=s;s*=(1-qf);qf*=q^m];s]/;
   (Precision[q]<Infinity && 0<=Abs[q]<1)

OrigQSF[q_,{n_,m_}]:=1/OrigQSF[1/q,{m-n,m}]/;
   (Precision[q]<Infinity && Abs[q]>1)


(**************************************************************)
(*              PartitionPGeneratingFunction[q]               *)
(**************************************************************)

PartitionPGeneratingFunction[0]:=1

PartitionPGeneratingFunction[1]:=Infinity

PartitionPGeneratingFunction[q_]:=
  Module[{s=0,so=1,k1=0},While[so!=s,so=s;
  s+=q^(k1^2)/QShiftedFactorial[q,q,k1]^2;k1++];s]/;
  (Precision[q]<Infinity && 0<Abs[q]<1)




(*************************  Order:2  **************************)

(**************************************************************)
(*                    SecondMockThetaA[q]                     *)
(**************************************************************)

SecondMockThetaA[q_]:=
  If[Abs[q]>=1,None,
    Module[{s=0,so=1,k=0,Nu1,Nu2,De},
      Nu1=q;Nu2=1;De=(1-q)^2;
      While[Abs[so-s]>(10^-8),so=s; s+=(Nu1*Nu2/De);
        Nu1*=(q^(2*k+3));
        Nu2*=(1+q^(2*k+1));
        De*=((1-q^(2*k+3))^2);k++];
      s]]/;
    (Precision[q]<Infinity)

(**************************************************************)
(*                    SecondMockThetaB[q]                     *)
(**************************************************************)

SecondMockThetaB[q_]:=
  If[Abs[q]>=1,None,
    Module[{s=0,so=1,k=0,Nu1,Nu2,De},
      Nu1=1;Nu2=1;De=(1-q)^2;
      While[Abs[so-s]>(10^-8),so=s; s+=(Nu1*Nu2/De);
        Nu1*=(q^(2*k+2));
        Nu2*=(1+q^(2*k+2));
        De*=((1-q^(2*k+3))^2);k++];
      s]]/;
    (Precision[q]<Infinity)

(**************************************************************)
(*                    SecondMockThetaMu[q]                    *)
(**************************************************************)

SecondMockThetaMu[q_]:=
  If[Abs[q]>=1,None,
    Module[{s=0,so=1,k=0,Nu1,Nu2,De},
      Nu1=1;Nu2=1;De=1;
      While[Abs[so-s]>(10^-8),so=s; s+=(Nu1*Nu2/De);
        Nu1*=(-1*q^(2*k+1));
        Nu2*=(1-q^(2*k+1));
        De*=((1+q^(2*k+2))^2);k++];
      s]]/;
    (Precision[q]<Infinity)



(*************************  Order:3  **************************)

(**************************************************************)
(*                     ThirdMockThetaF[q]                     *)
(**************************************************************)

ThirdMockThetaF[0]:=1

ThirdMockThetaF[1]:=4/3

ThirdMockThetaF[q_]:=
  If[Abs[q]>=1,None,
    Module[{s=0,so=1,k=0,Nu,De},
      Nu=1;De=1;
      While[Abs[so-s]>(10^-8),so=s; s+=(Nu/De);
        Nu*=(q^(2*k+1));
        De*=((1+q^(k+1))^2);k++];
      s]]/;
    (Precision[q]<Infinity)

(**************************************************************)
(*                    ThirdMockThetaPhi[q]                    *)
(**************************************************************)

ThirdMockThetaPhi[0]:=1

ThirdMockThetaPhi[1]:=2

ThirdMockThetaPhi[q_]:=
  If[Abs[q]>=1,None,
    Module[{s=0,so=1,k=0,Nu,De},
      Nu=1;De=1;
      While[Abs[so-s]>(10^-8),so=s; s+=(Nu/De);
        Nu*=(q^(2*k+1));
        De*=(1+q^(2*k+2));k++];
      s]]/;
    (Precision[q]<Infinity)

(**************************************************************)
(*                    ThirdMockThetaPsi[q]                    *)
(**************************************************************)

ThirdMockThetaPsi[0]:=1

ThirdMockThetaPsi[1]:=Infinity

ThirdMockThetaPsi[q_]:=
  If[Abs[q]>=1,None,
    Module[{s=0,so=1,k=0,Nu,De},
      Nu=1;De=1;
      While[Abs[so-s]>(10^-8),so=s; s+=(Nu/De);
        Nu*=(q^(2*k+1));
        De*=(1-q^(2*k+1));k++];
      s]]/;
    (Precision[q]<Infinity)

(**************************************************************)
(*                   ThirdMockThetaOmega[q]                   *)
(**************************************************************)

ThirdMockThetaOmega[0]:=1

ThirdMockThetaOmega[1]:=Infinity

ThirdMockThetaOmega[q_]:=
  If[Abs[q]>=1,None,
    Module[{s=0,so=1,k=0,Nu,De},
      Nu=1;De=(1-q)^2;
      While[Abs[so-s]>(10^-8),so=s; s+=(Nu/De);
        Nu*=(q^(4*k+4));
        De*=((1-q^(2*k+3))^2);k++];
      s]]/;
    (Precision[q]<Infinity)

(**************************************************************)
(*                    ThirdMockThetaNu[q]                     *)
(**************************************************************)

ThirdMockThetaNu[0]:=1

ThirdMockThetaNu[1]:=1

ThirdMockThetaNu[q_]:=
  If[Abs[q]>=1,None,
    Module[{s=0,so=1,k=0,Nu,De},
      Nu=1;De=(1+q);
      While[Abs[so-s]>(10^-8),so=s; s+=(Nu/De);
        Nu*=(q^(2*k+2));
        De*=(1+q^(2*k+3));k++];
      s]]/;
    (Precision[q]<Infinity)

(**************************************************************)
(*                    ThirdMockThetaChi[q]                    *)
(**************************************************************)

ThirdMockThetaChi[q_]:=
  If[Abs[q]>=1,None,
    Module[{s=0,so=1,k=0,Nu,De},
      Nu=1;De=1;
      While[Abs[so-s]>(10^-8),so=s; s+=(Nu/De);
        Nu*=(q^(2*k+1));
        De*=(1-q^(k+1)+q^(2*k+2));k++];
      s]]/;
    (Precision[q]<Infinity)

(**************************************************************)
(*                    ThirdMockThetaRho[q]                    *)
(**************************************************************)

ThirdMockThetaRho[q_]:=
  If[Abs[q]>=1,None,
    Module[{s=0,so=1,k=0,Nu,De},
      Nu=1;De=(1+q+q^2);
      While[Abs[so-s]>(10^-8),so=s; s+=(Nu/De);
        Nu*=(q^(4*k+4));
        De*=(1+q^(2*k+3)+q^(4*k+6));k++];
      s]]/;
    (Precision[q]<Infinity)



(*************************  Order:5  **************************)

(**************************************************************)
(*                    FifthMockThetaF0[q]                     *)
(**************************************************************)

FifthMockThetaF0[q_]:=
  If[Abs[q]>=1,None,
    Module[{s=0,so=1,k=0,Nu,De},
      Nu=1;De=1;
      While[Abs[so-s]>(10^-8),so=s; s+=(Nu/De);
        Nu*=(q^(2*k+1));
        De*=(1+q^(k+1));k++];
      s]]/;
    (Precision[q]<Infinity)

(**************************************************************)
(*                    FifthMockThetaF1[q]                     *)
(**************************************************************)

FifthMockThetaF1[q_]:=
  If[Abs[q]>=1,None,
    Module[{s=0,so=1,k=0,Nu,De},
      Nu=1;De=1;
      While[Abs[so-s]>(10^-8),so=s; s+=(Nu/De);
        Nu*=(q^(2*k+2));
        De*=(1+q^(k+1));k++];
      s]]/;
    (Precision[q]<Infinity)

(**************************************************************)
(*                   FifthMockThetaPhi0[q]                    *)
(**************************************************************)

FifthMockThetaPhi0[q_]:=
  If[Abs[q]>=1,None,
    Module[{s=0,so=1,k=0,Nu1,Nu2},
      Nu1=1;Nu2=1;
      While[Abs[so-s]>(10^-8),so=s; s+=(Nu1*Nu2);
        Nu1*=(q^(2*k+1));
        Nu2*=(1+q^(2*k+1));k++];
      s]]/;
    (Precision[q]<Infinity)

(**************************************************************)
(*                   FifthMockThetaPhi1[q]                    *)
(**************************************************************)

FifthMockThetaPhi1[q_]:=
  If[Abs[q]>=1,None,
    Module[{s=0,so=1,k=0,Nu1,Nu2},
      Nu1=q;Nu2=1;
      While[Abs[so-s]>(10^-8),so=s; s+=(Nu1*Nu2);
        Nu1*=(q^(2*k+3));
        Nu2*=(1+q^(2*k+1));k++];
      s]]/;
    (Precision[q]<Infinity)

(**************************************************************)
(*                   FifthMockThetaPsi0[q]                    *)
(**************************************************************)

FifthMockThetaPsi0[q_]:=
  If[Abs[q]>=1,None,
    Module[{s=0,so=1,k=0,Nu1,Nu2},
      Nu1=q;Nu2=1;
      While[Abs[so-s]>(10^-8),so=s; s+=(Nu1*Nu2);
        Nu1*=(q^(k+2));
        Nu2*=(1+q^(k+1));k++];
      s]]/;
    (Precision[q]<Infinity)

(**************************************************************)
(*                   FifthMockThetaPsi1[q]                    *)
(**************************************************************)

FifthMockThetaPsi1[q_]:=
  If[Abs[q]>=1,None,
    Module[{s=0,so=1,k=0,Nu1,Nu2},
      Nu1=1;Nu2=1;
      While[Abs[so-s]>(10^-8),so=s; s+=(Nu1*Nu2);
        Nu1*=(q^(k+1));
        Nu2*=(1+q^(k+1));k++];
      s]]/;
    (Precision[q]<Infinity)

(**************************************************************)
(*                   FifthMockThetaChi0[q]                    *)
(**************************************************************)

FifthMockThetaChi0[q_]:=
  If[Abs[q]>=1,None,
  2*FifthMockThetaLargeF0[q]-FifthMockThetaPhi0[-q]]/;
  (Precision[q]<Infinity)

(**************************************************************)
(*                   FifthMockThetaChi1[q]                    *)
(**************************************************************)

FifthMockThetaChi1[q_]:=
  If[Abs[q]>=1,None,
  2*FifthMockThetaLargeF1[q]+FifthMockThetaPhi1[-q]/q]/;
  (Precision[q]<Infinity)

(**************************************************************)
(*                  FifthMockThetaLargeF0[q]                  *)
(**************************************************************)

FifthMockThetaLargeF0[q_]:=
  If[Abs[q]>=1,None,
    Module[{s=0,so=1,k=0,Nu,De},
      Nu=1;De=1;
      While[Abs[so-s]>(10^-8),so=s; s+=(Nu/De);
        Nu*=(q^(4*k+2));
        De*=(1-q^(2*k+1));k++];
      s]]/;
    (Precision[q]<Infinity)

(**************************************************************)
(*                  FifthMockThetaLargeF1[q]                  *)
(**************************************************************)

FifthMockThetaLargeF1[q_]:=
  If[Abs[q]>=1,None,
    Module[{s=0,so=1,k=0,Nu,De},
      Nu=1;De=(1-q);
      While[Abs[so-s]>(10^-8),so=s; s+=(Nu/De);
        Nu*=(q^(4*k+4));
        De*=(1-q^(2*k+3));k++];
      s]]/;
    (Precision[q]<Infinity)



(*************************  Order:6  **************************)

(**************************************************************)
(*                    SixthMockThetaPhi[q]                    *)
(**************************************************************)

SixthMockThetaPhi[q_]:=
  If[Abs[q]>=1,None,
    Module[{s=0,so=1,k=0,Nu1,Nu2,De},
      Nu1=1;Nu2=1;De=1;
      While[Abs[so-s]>(10^-8),so=s; s+=(Nu1*Nu2/De);
        Nu1*=(-1*q^(2*k+1));
        Nu2*=(1-q^(2*k+1));
        De*=((1+q^(2 k+1))(1+q^(2 k+2)));k++];
      s]]/;
    (Precision[q]<Infinity)

(**************************************************************)
(*                    SixthMockThetaPsi[q]                    *)
(**************************************************************)

SixthMockThetaPsi[q_]:=
  If[Abs[q]>=1,None,
    Module[{s=0,so=1,k=0,Nu1,Nu2,De},
      Nu1=q;Nu2=1;De=(1+q);
      While[Abs[so-s]>(10^-8),so=s; s+=(Nu1*Nu2/De);
        Nu1*=(-1*q^(2*k+3));
        Nu2*=(1-q^(2*k+1));
        De*=((1+q^(2 k+2))(1+q^(2 k+3)));k++];
      s]]/;
    (Precision[q]<Infinity)

(**************************************************************)
(*                    SixthMockThetaRho[q]                    *)
(**************************************************************)

SixthMockThetaRho[q_]:=
  If[Abs[q]>=1,None,
    Module[{s=0,so=1,k=0,Nu1,Nu2,De},
      Nu1=1;Nu2=1;De=(1-q);
      While[Abs[so-s]>(10^-8),so=s; s+=(Nu1*Nu2/De);
        Nu1*=(q^(k+1));
        Nu2*=(1+q^(k+1));
        De*=(1-q^(2*k+3));k++];
      s]]/;
    (Precision[q]<Infinity)

(**************************************************************)
(*                   SixthMockThetaSigma[q]                   *)
(**************************************************************)

SixthMockThetaSigma[q_]:=
  If[Abs[q]>=1,None,
    Module[{s=0,so=1,k=0,Nu1,Nu2,De},
      Nu1=q;Nu2=1;De=(1-q);
      While[Abs[so-s]>(10^-8),so=s; s+=(Nu1*Nu2/De);
        Nu1*=(q^(k+2));
        Nu2*=(1+q^(k+1));
        De*=(1-q^(2*k+3));k++];
      s]]/;
    (Precision[q]<Infinity)

(**************************************************************)
(*                  SixthMockThetaLambda[q]                   *)
(**************************************************************)

SixthMockThetaLambda[q_]:=
  If[Abs[q]<1,
    OrigQSF[q,{1,2}]^2*OrigQSF[q,{1,6}]*OrigQSF[q,{5,6}]*OrigQSF[q,{6,6}]+
    2/q*SixthMockThetaPsi[q^2]]/;
  (Precision[q]<Infinity)

(**************************************************************)
(*                    SixthMockThetaMu[q]                     *)
(**************************************************************)

SixthMockThetaMu[q_]:=
  If[Abs[q]<1,
    SixthMockThetaPhi[q^2]-OrigQSF[q,{1,2}]^2*OrigQSF[q,{3,6}]^2*
    OrigQSF[q,{6,6}]/2]/;
  (Precision[q]<Infinity)

(**************************************************************)
(*                   SixthMockThetaGamma[q]                   *)
(**************************************************************)

SixthMockThetaGamma[q_]:=
  If[Abs[q]>=1,None,
    Module[{s=0,so=1,k=0,Nu1,Nu2,De},
      Nu1=1;Nu2=1;De=1;
      While[Abs[so-s]>(10^-8),so=s; s+=(Nu1*Nu2/De);
        Nu1*=(q^(2*k+1));
        Nu2*=(1-q^(k+1));
        De*=(1-q^(3*k+3));k++];
      s]]/;
    (Precision[q]<Infinity)



(*************************  Order:7  **************************)

(**************************************************************)
(*                   SeventhMockThetaF0[q]                    *)
(**************************************************************)

SeventhMockThetaF0[q_]:=
  If[Abs[q]>=1,None,
    Module[{s=0,so=1,k=0,Nu1,Nu2,De},
      Nu1=q;Nu2=1;De=(1-q^2);
      While[Abs[so-s]>(10^-8),so=s; s+=(Nu1*Nu2/De);
        Nu1*=(q^(2*k+3));
        Nu2*=(1-q^(k+2));
        De*=((1-q^(2*k+3))*(1-q^(2*k+4)));k++];
      s+1]]/;
    (Precision[q]<Infinity)

(**************************************************************)
(*                   SeventhMockThetaF1[q]                    *)
(**************************************************************)

SeventhMockThetaF1[q_]:=
  If[Abs[q]>=1,None,
    Module[{s=0,so=1,k=0,Nu1,Nu2,De},
      Nu1=q;Nu2=1;De=(1-q);
      While[Abs[so-s]>(10^-8),so=s; s+=(Nu1*Nu2/De);
        Nu1*=(q^(2*k+3));
        Nu2*=(1-q^(k+1));
        De*=((1-q^(2*k+2))*(1-q^(2*k+3)));k++];
      s+1]]/;
    (Precision[q]<Infinity)

(**************************************************************)
(*                   SeventhMockThetaF2[q]                    *)
(**************************************************************)

SeventhMockThetaF2[q_]:=
  If[Abs[q]>=1,None,
    Module[{s=0,so=1,k=0,Nu1,Nu2,De},
      Nu1=1;Nu2=1;De=(1-q);
      While[Abs[so-s]>(10^-8),so=s; s+=(Nu1*Nu2/De);
        Nu1*=(q^(2*k+2));
        Nu2*=(1-q^(k+1));
        De*=((1-q^(2*k+2))*(1-q^(2*k+3)));k++];
      s]]/;
    (Precision[q]<Infinity)



(*************************  Andrews  **************************)


(**************************************************************)
(*                   AndrewsMockTheta3[q,t]                   *)
(**************************************************************)

AndrewsMockTheta3[q_,t_]:=
  Module[{s=0,so=-1,k1=0,tf,qf},tf=1;qf=1;
   While[so!=s,so=s;
     s+=N[tf*qf/(QShiftedFactorial[t*q,q,k1]^2)];
     tf*=(t^2);qf*=(q^(2 k1+1));k1++];s]/(1-t)/;
     (Precision[t]<Infinity && Precision[q]<Infinity && 
     0<Abs[q]<1)

AndrewsMockTheta3[q_,t_]:=1/(1-t)/;(N[q]===0.)

AndrewsMockTheta3[q_,t_]:=
  (1-t)/(1-2 t)/;(N[q]===1.)

AndrewsMockTheta3[q_,t_]:=
  (1-3 t^2+2 t^3)/((1-t)*(1-2 t^2))/;(N[q]===-1.)


(**************************************************************)
(*                   AndrewsMockTheta5[q,t]                   *)
(**************************************************************)

AndrewsMockTheta5[q_,t_]:=
  Module[{s=0,so=-1,k1=0,tf,qf},tf=1;qf=1;
   While[so!=s,so=s;
     s+=N[tf*qf/(QShiftedFactorial[t,q,k1+1])];
     tf*=(t^2);qf*=(q^(2 k1+1));k1++];s]/;
     (Precision[t]<Infinity && Precision[q]<Infinity && 
     0<Abs[q]<1)

AndrewsMockTheta5[q_,t_]:=1/(1-t)/;(N[q]===0.)

AndrewsMockTheta5[q_,t_]:=
  1/(1-t-t^2)/;(N[q]===1.)

AndrewsMockTheta5[q_,t_]:=
  (1+t-t^2)/(1-t^2-t^4)/;(N[q]===-1.)


(**************************************************************)
(*                   AndrewsMockTheta7[q,t]                   *)
(**************************************************************)

AndrewsMockTheta7[q_,t_]:=
  Module[{s=0,so=-1,k1=0,tf,qf},tf=1;qf=1;
   While[so!=s,so=s;
     s+=N[tf*qf/(QShiftedFactorial[t,q,k1+1]*
       QShiftedFactorial[q*t^2,q^2,k1])];
     tf*=(t^2);qf*=(q^(2 k1+1));k1++];s]/;
     (Precision[t]<Infinity && Precision[q]<Infinity && 
     0<Abs[q]<1)

AndrewsMockTheta7[q_,t_]:=1/(1-t)/;(N[q]===0.)

AndrewsMockTheta7[q_,t_]:=
  (1-t^2)/(1-t-2 t^2+t^3)/;(N[q]===1.)

AndrewsMockTheta7[q_,t_]:=
  (1+t+t^2+2 t^3+t^5)/(1+t^2-2 t^4-t^6)/;(N[q]===-1.)




(***********************  Andrews Cos  ************************)


(**************************************************************)
(*                 AndrewsMockTheta3Cos[q,t]                  *)
(**************************************************************)

AndrewsMockTheta3Cos[q_,t_]:=
  Module[{s=0,so=-1,k1=0,qf},qf=1;
   While[so!=s,so=s;
     s+=N[Cos[2 k1 t]*qf/(QShiftedFactorial[q*t,q,k1]^2)];
     qf*=(q^(2 k1+1));k1++];s]/(1-t)/;
     (Precision[t]<Infinity && Precision[q]<Infinity)


(**************************************************************)
(*                 AndrewsMockTheta5Cos[q,t]                  *)
(**************************************************************)

AndrewsMockTheta5Cos[q_,t_]:=
  Module[{s=0,so=-1,k1=0,qf},qf=1;
   While[so!=s,so=s;
     s+=N[Cos[2 k1 t]*qf/(QShiftedFactorial[t,q,k1+1])];
     qf*=(q^(2 k1+1));k1++];s]/;
     (Precision[t]<Infinity && Precision[q]<Infinity && 
     0<Abs[q]<1)


(**************************************************************)
(*                 AndrewsMockTheta7Cos[q,t]                  *)
(**************************************************************)

AndrewsMockTheta7Cos[q_,t_]:=
  Module[{s=0,so=-1,k1=0,qf},qf=1;
   While[so!=s,so=s;
     s+=N[Cos[2 k1 t]*qf/(QShiftedFactorial[t,q,k1+1]*
       QShiftedFactorial[q*t^2,q^2,k1])];
     qf*=(q^(2 k1+1));k1++];s]/;
     (Precision[t]<Infinity && Precision[q]<Infinity && 
     0<Abs[q]<1)




(*********************  some q-Series  ***********************)


(**************************************************************)
(*                    RogersRamanujanR1[q],...                *)
(**************************************************************)

RogersRamanujanR1[q_]:=
  q^(-1/60)/OrigQSF[q,{1,5}]/OrigQSF[q,{4,5}];

RogersRamanujanR2[q_]:=
  q^(11/60)/OrigQSF[q,{2,5}]/OrigQSF[q,{3,5}];


(**************************************************************)
(*                    RogersRamanujanC[q]                     *)
(**************************************************************)

RogersRamanujanC[1]:=GoldenRatio-1

RogersRamanujanC[q_]:=0/;(N[Abs[q]]===0. && Precision[q]<Infinity)

RogersRamanujanC[q_]:=
  Fold[(q^#2/(1+#1))&,0,
  Range[2*Ceiling[Abs[10*Log[Abs[q],10]]/2],0,-1]]*q^(1/5)/;
  (Abs[q]>0 && Precision[q]<Infinity)


(**************************************************************)
(*             GeneralizedRogersRamanujanR[a,b,q]             *)
(**************************************************************)

GeneralizedRogersRamanujanR[a_,b_,q_]:=
  a/(1+b)/;(N[Abs[q]]===0. && Precision[q]<Infinity)

GeneralizedRogersRamanujanR[a_,b_,q_]:=
  Fold[(a*q^#2/(1+b*q^#2+#1))&,0,
  Range[2*Ceiling[Abs[10*Log[Abs[q],10]]/2],0,-1]]/;
  (Abs[q]>0 && Precision[q]<Infinity)


GeneralizedRogersRamanujanR[a_,q_]:=
  GeneralizedRogersRamanujanR[a,0,q]/a


(**************************************************************)
(*              GeneralizedRogersRamanujanF[a,q]              *)
(**************************************************************)

GeneralizedRogersRamanujanF[a_,q_]:=
  1/GeneralizedRogersRamanujanR[-a,q]


(**************************************************************)
(*                   BaileyMod9First[q],...                   *)
(**************************************************************)

BaileyMod9First[q_]:=
  OrigQSF[q,{4,9}]*OrigQSF[q,{5,9}]*OrigQSF[q,{9,9}]/
  OrigQSF[q,{3,3}];

BaileyMod9Second[q_]:=
  OrigQSF[q,{2,9}]*OrigQSF[q,{7,9}]*OrigQSF[q,{9,9}]/
  OrigQSF[q,{3,3}];

BaileyMod9Third[q_]:=
  OrigQSF[q,{1,9}]*OrigQSF[q,{8,9}]*OrigQSF[q,{9,9}]/
  OrigQSF[q,{3,3}];


(**************************************************************)
(*                   RogersMod14First[q],...                  *)
(**************************************************************)

RogersMod14First[q_]:=
  OrigQSF[q,{6,14}]*OrigQSF[q,{8,14}]*OrigQSF[q,{14,14}]/
  OrigQSF[q,{1,1}];

RogersMod14Second[q_]:=
  OrigQSF[q,{4,14}]*OrigQSF[q,{10,14}]*OrigQSF[q,{14,14}]/
  OrigQSF[q,{1,1}];

RogersMod14Third[q_]:=
  OrigQSF[q,{2,14}]*OrigQSF[q,{12,14}]*OrigQSF[q,{14,14}]/
  OrigQSF[q,{1,1}];


(**************************************************************)
(*                  RogersSelbergFirst[q],...                 *)
(**************************************************************)

RogersSelbergFirst[q_]:=
  OrigQSF[q,{3,7}]*OrigQSF[q,{4,7}]*OrigQSF[q,{7,7}]/
  OrigQSF[q,{2,2}];

RogersSelbergSecond[q_]:=
  OrigQSF[q,{2,7}]*OrigQSF[q,{5,7}]*OrigQSF[q,{7,7}]/
  OrigQSF[q,{2,2}];

RogersSelbergThird[q_]:=
  OrigQSF[q,{1,7}]*OrigQSF[q,{6,7}]*OrigQSF[q,{7,7}]/
  OrigQSF[q,{2,2}];


(**************************************************************)
(*                 GoellnitzGordonFirst[q],...                *)
(**************************************************************)

GoellnitzGordonFirst[q_]:=
  1/OrigQSF[q,{1,8}]/OrigQSF[q,{4,8}]/OrigQSF[q,{7,8}];

GoellnitzGordonSecond[q_]:=
  1/OrigQSF[q,{3,8}]/OrigQSF[q,{4,8}]/OrigQSF[q,{5,8}];


(**************************************************************)
(*                      JacksonSlater[q]                      *)
(**************************************************************)

JacksonSlater[q_]:=
  OrigQSF[q,{1,8}]*OrigQSF[q,{7,8}]*OrigQSF[q,{8,8}]*
  OrigQSF[q,{6,16}]*OrigQSF[q,{10,16}]/OrigQSF[q,{1,1}];


(**************************************************************)
(*                   DysonMod27First[q],...                   *)
(**************************************************************)

DysonMod27First[q_]:=
  OrigQSF[q,{12,27}]*OrigQSF[q,{15,27}]*OrigQSF[q,{27,27}]/
  OrigQSF[q,{1,1}];

DysonMod27Second[q_]:=
  OrigQSF[q,{9,9}]/OrigQSF[q,{1,1}];

DysonMod27Third[q_]:=
  OrigQSF[q,{6,27}]*OrigQSF[q,{21,27}]*OrigQSF[q,{27,27}]/
  OrigQSF[q,{1,1}];

DysonMod27Fourth[q_]:=
  OrigQSF[q,{3,27}]*OrigQSF[q,{24,27}]*OrigQSF[q,{27,27}]/
  OrigQSF[q,{1,1}];




(**************************************************************)

End[]

Protect[OrigQSF, PartitionPGeneratingFunction, 
   SecondMockThetaA, SecondMockThetaB, SecondMockThetaMu, 
   ThirdMockThetaF, ThirdMockThetaPhi, ThirdMockThetaPsi, 
   ThirdMockThetaChi, ThirdMockThetaRho, ThirdMockThetaOmega, 
   ThirdMockThetaNu,  ThirdMockThetaChi, ThirdMockThetaRho, 
   FifthMockThetaF0, FifthMockThetaF1, FifthMockThetaPhi0, 
   FifthMockThetaPhi1, FifthMockThetaPsi0, FifthMockThetaPsi1, 
   FifthMockThetaChi0, FifthMockThetaChi1, FifthMockThetaLargeF0, 
   FifthMockThetaLargeF1, 
   SixthMockThetaPhi, SixthMockThetaPsi, SixthMockThetaRho, 
   SixthMockThetaSigma, SixthMockThetaLambda, SixthMockThetaMu, 
   SixthMockThetaGamma, 
   SeventhMockThetaF0, SeventhMockThetaF1, SeventhMockThetaF2, 
   AndrewsMockTheta3, AndrewsMockTheta5, AndrewsMockTheta7, 
   AndrewsMockTheta3Cos, AndrewsMockTheta5Cos, AndrewsMockTheta7Cos, 
   RogersRamanujanR1, RogersRamanujanR2, RogersRamanujanC, 
   GeneralizedRogersRamanujanR, GeneralizedRogersRamanujanF, 
   BaileyMod9First, BaileyMod9Second, BaileyMod9Third, 
   RogersMod14First, RogersMod14Second, RogersMod14Third, 
   RogersSelbergFirst, RogersSelbergSecond, RogersSelbergThird, 
   GoellnitzGordonFirst, GoellnitzGordonSecond, JacksonSlater, 
   DysonMod27First, DysonMod27Second, DysonMod27Third, 
   DysonMod27Fourth]

EndPackage[]
